Smrti Visualizer
Tenant
Space
API
Types:
Concept
Belief
Episode
Goal
Conf ≥ 0.00
Limit
Auto-refresh
Loading graph…

##### Nodes

Concept
Belief
Episode
Goal

##### Size = LTI

Neg valence
Pos valence

##### Edges

Relation →
Hover to highlight · Click to inspect Drag to move · Shift+drag to pin
concept context
Probability
—
Confidence
—
STI
—
LTI
—
Intensity
—
Valence 0.00
−10+1
Entity type
Relation
Source →
→ Target
Space
Created
Updated
Metadata

⧉
connecting…
⬡ 0 nodes
↗ 0 edges
personality: —
epochs: —
refreshed: —
prob: · conf:
STI: · LTI: